<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ComDialog</name>
    <message>
        <source>INFO</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Connected to </source>
        <translation>Verbunden mit</translation>
    </message>
    <message>
        <source>Connecting to </source>
        <translation>Verbinden mit</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Verbindung getrennt</translation>
    </message>
    <message>
        <source>Qtel Error</source>
        <translation>Qtel Fehler</translation>
    </message>
    <message>
        <source>Station data not found in directory server.
Can&apos;t create connection to</source>
        <translation>Stationsdaten nicht im Echolink-Verzeichnisserver gefunden. 
	Es kann keine Verbindung aufgebaut werden zu</translation>
    </message>
    <message>
        <source>Could not create connection to remote host</source>
        <translation>Es kann keine Verbindung aufgebaut werden zum Host</translation>
    </message>
    <message>
        <source>Could not open mic audio device</source>
        <translation>Das Eingabegerät (Mikrofoneingang) kann nicht geöffnet werden</translation>
    </message>
    <message>
        <source>Could not open speaker audio device</source>
        <translation>Das Ausgabegerät (Lautsprecherausgang) kann nicht geöffnet werden</translation>
    </message>
    <message>
        <source>Could not create connection to</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ComDialogBase</name>
    <message>
        <source>Communication Dialog</source>
        <translation>Kommunikationsdialog</translation>
    </message>
    <message>
        <source>Station Information</source>
        <translation>Stationsinformation</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>IP-address:</source>
        <translation>IP-Adresse:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Zeit:</translation>
    </message>
    <message>
        <source>PTT</source>
        <translation>PTT</translation>
    </message>
    <message>
        <source>Chat/Info</source>
        <translation>Mitteilungen</translation>
    </message>
    <message>
        <source>&amp;Connect</source>
        <translation>&amp;Verbinden</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Verbindung trennen</translation>
    </message>
    <message>
        <source>RX</source>
        <translation>RX</translation>
    </message>
    <message>
        <source>TX</source>
        <translation>TX</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Alt+D</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <source>VOX</source>
        <translation>VOX</translation>
    </message>
    <message>
        <source>VOX Enabled</source>
        <translation>VOX aktiviert</translation>
    </message>
    <message>
        <source>Threshold:</source>
        <translation>Schwellwert:</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Verzögerung:</translation>
    </message>
    <message>
        <source>dB Level:</source>
        <translation>Pegel [dB]:</translation>
    </message>
</context>
<context>
    <name>EchoLinkDirectoryModel</name>
    <message>
        <source>Callsign</source>
        <translation>Rufzeichen</translation>
    </message>
    <message>
        <source>Location/Description</source>
        <translation>Ort/Beschreibung</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Local Time</source>
        <translation>Lokalzeit</translation>
    </message>
    <message>
        <source>Node ID</source>
        <translation>Knotennummer</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-Adresse</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Logging off from directory server...</source>
        <translation>Beim Verzeichnisserver abmelden...</translation>
    </message>
    <message>
        <source>Station list has been refreshed</source>
        <translation>Die Stationsliste wurde aktualisiert</translation>
    </message>
    <message>
        <source>Refreshing station list...</source>
        <translation>Aktualisiere Stationsliste...</translation>
    </message>
    <message>
        <source>Qtel - Add station...</source>
        <translation>Qtel - Station hinzufügen...</translation>
    </message>
    <message>
        <source>Enter callsign of the station to add</source>
        <translation>Rufzeichen der Station, die hinzugefügt werden soll</translation>
    </message>
    <message>
        <source>Qtel: Connect to IP</source>
        <translation>Qtel: Verbinden mit IP</translation>
    </message>
    <message>
        <source>Enter an IP address or hostname:</source>
        <translation>IP-Adresse oder Hostnamen eingeben:</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <source>Links</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Repeaters</source>
        <translation>Relais</translation>
    </message>
    <message>
        <source>Conferences</source>
        <translation>Konferenzen</translation>
    </message>
    <message>
        <source>Stations</source>
        <translation>Stationen</translation>
    </message>
    <message>
        <source>About Qtel</source>
        <translation>über Qtel</translation>
    </message>
    <message>
        <source>Qtel v</source>
        <translation>Qtel v</translation>
    </message>
    <message>
        <source> - Qt EchoLink client.
</source>
        <translation>- QT EchoLink Programm.
</translation>
    </message>
    <message>
        <source>Copyright (C) 2011 Tobias Blomberg / SM0SVX

Qtel comes with ABSOLUTELY NO WARRANTY. This is free software, and you are welcome to redistribute it in accordance with the terms and conditions in the GNU GPL (General Public License) version 2 or later.</source>
        <translation>Copyright (C) 2011 Tobias Blomberg / SM0SVX

Qtel wird OHNE JEGLICHE GARANTIE veröffentlicht. Dies ist freie Software und Sie sind berechtigt diese unter Beachtung der Bedingungen und Konditionen der GNU GPL (General Public License) version 2 oder neuer zu nutzen und weiterzuverbreiten.</translation>
    </message>
</context>
<context>
    <name>MainWindowBase</name>
    <message>
        <source>Conferences</source>
        <translation>Konferenzen</translation>
    </message>
    <message>
        <source>Links</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Repeaters</source>
        <translation>Relais</translation>
    </message>
    <message>
        <source>Stations</source>
        <translation>Stationen</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>&amp;Über...</translation>
    </message>
    <message>
        <source>About Qtel</source>
        <translation>über Qtel</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Quit the Qtel application</source>
        <translation>Qtel beenden</translation>
    </message>
    <message>
        <source>Qtel Settings...</source>
        <translation>Einstellungen für Qtel...</translation>
    </message>
    <message>
        <source>Open the Qtel settings dialog</source>
        <translation>Einstellungen für Qtel öffnen</translation>
    </message>
    <message>
        <source>&amp;Directory</source>
        <translation>&amp;Stationsverzeichnis</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>&amp;Refresh</source>
        <translation>A&amp;ktualisieren</translation>
    </message>
    <message>
        <source>Refresh station list</source>
        <translation>Stationsliste aktualisieren</translation>
    </message>
    <message>
        <source>Qtel - the Qt EchoLink Client</source>
        <translation>Qtel - der Qt EchoLink Client</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>&amp;Busy</source>
        <translation>&amp;Beschäftigt</translation>
    </message>
    <message>
        <source>View as busy</source>
        <translation>Als beschäftigt anzeigen</translation>
    </message>
    <message>
        <source>View as busy in directory server</source>
        <translation>Im Verzeichnisserver als beschäftigt anzeigen</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Mitteilungen</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Akzeptieren</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Callsign</source>
        <translation>Rufzeichen</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Connect to IP...</source>
        <translation>Verbinde mit IP...</translation>
    </message>
    <message>
        <source>Connect to selected...</source>
        <translation>Mit ausgewählter Station verbinden...</translation>
    </message>
    <message>
        <source>Incoming Connections</source>
        <translation>Eingehende Verbindungen</translation>
    </message>
    <message>
        <source>&amp;Station</source>
        <translation>&amp;Station</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>Connect to &amp;selected...</source>
        <translation>Verbinde zur ausgewählten &amp;Station...</translation>
    </message>
    <message>
        <source>Connect to &amp;IP...</source>
        <translation>Verbinde mit &amp;IP...</translation>
    </message>
    <message>
        <source>Qtel &amp;Settings...</source>
        <translation>QTel Ein&amp;stellungen...</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Add Selected To &amp;Bookmarks</source>
        <translation>Füge die ausgewählte Station zu den &amp;Favoriten hinzu</translation>
    </message>
    <message>
        <source>Add the selected station in the station list to the bookmarks menu</source>
        <translation>Füge die ausgewählte Station der Stationsliste unter Favoriten hinzu</translation>
    </message>
    <message>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <source>&amp;Remove Selected From Bookmarks</source>
        <translation>&amp;Entferne das Ausgewählte aus der Liste der Favoriten</translation>
    </message>
    <message>
        <source>Remove the selected station from the bookmarks list</source>
        <translation>Entferne die ausgewählte Station aus der Liste der Favoriten</translation>
    </message>
    <message>
        <source>Add &amp;Named Station To Bookmarks</source>
        <translation>Be&amp;nannte Station der Favoritenliste hinzufügen</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Connect to the selected station</source>
        <translation>Mit der ausgewählten Station verbinden</translation>
    </message>
    <message>
        <source>Connect to local station using IP address or hostname</source>
        <translation>Mit der Lokalstation über die IP-Adresse oder Hostnamen verbinden</translation>
    </message>
    <message>
        <source>Immediately refresh the station list</source>
        <translation>Sofortiges Auffrischen der Stationsliste</translation>
    </message>
    <message>
        <source>Add selected station to the bookmarks</source>
        <translation>Ausgewählte Station der Favoritenliste hinzufügen</translation>
    </message>
    <message>
        <source>Remove the selected station from the bookmarks</source>
        <translation>Ausgewählte Station aus der Liste der Favoriten entfernen</translation>
    </message>
    <message>
        <source>Add a station to the bookmarks by entering a callsign</source>
        <translation>Eine neue Station durch Eingabe eines Rufzeichens hinzufügen</translation>
    </message>
    <message>
        <source>Show the about dialog</source>
        <translation>Über QTel</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Qtel: Settings</source>
        <translation>Qtel: Einstellungen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>User Info</source>
        <translation>Info zur Gegenstation</translation>
    </message>
    <message>
        <source>User Information</source>
        <translation>Informationen zur Gegenstation</translation>
    </message>
    <message>
        <source>Info
Message</source>
        <translation>Information/Mitteilung
</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ort</translation>
    </message>
    <message>
        <source>Callsign</source>
        <translation>Rufzeichen</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Retype password</source>
        <translation>Passwort nochmals eingeben</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Directory Server Settings</source>
        <translation>Verzeichnisservereinstellungen</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Refresh time</source>
        <translation>Aktualisierungsintervall</translation>
    </message>
    <message>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <source>Time, in minutes, between station list refreshes</source>
        <translation>Intervall in Minuten zwischen den Aktualisierungen</translation>
    </message>
    <message>
        <source>Register as busy on program startup</source>
        <translation>Beim Programmstart als beschäftigt anmelden</translation>
    </message>
    <message>
        <source>Start as busy</source>
        <translation>Beim Programmstart als beschäftigt anzeigen</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Full duplex</source>
        <translation>Vollduplex</translation>
    </message>
    <message>
        <source>Check this check box to enable full duplex operation</source>
        <translation>Zum Vollduplex-Betrieb diese Checkbox anklicken</translation>
    </message>
    <message>
        <source>Connect Sound</source>
        <translation>Ton beim Verbindungsaufbau</translation>
    </message>
    <message>
        <source>The connect sound to use on incoming EchoLink connections</source>
        <translation>Ton für eingehende Verbindung</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Durchsuchen...</translation>
    </message>
    <message>
        <source>Raw Sound Files (*.raw)</source>
        <translation>16-bit 8kHz Audio-Datei (*.raw)</translation>
    </message>
    <message>
        <source>Choose a connect sound file</source>
        <translation>Audiodatei auswählen</translation>
    </message>
    <message>
        <source>QSO</source>
        <translation>QSO</translation>
    </message>
    <message>
        <source>Chat encoding:</source>
        <translation>Chat-Sprache:</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinesisch</translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation>Japanisch</translation>
    </message>
    <message>
        <source>Korean</source>
        <translation>Koreanisch</translation>
    </message>
    <message>
        <source>Tamil</source>
        <translation>Tamilisch</translation>
    </message>
    <message>
        <source>Unicode, 8-bit</source>
        <translation>Unicode, 8-Bit</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Russisch</translation>
    </message>
    <message>
        <source>Ukrainian</source>
        <translation>Ukrainisch</translation>
    </message>
    <message>
        <source>Western</source>
        <translation>Westlich</translation>
    </message>
    <message>
        <source>Central European</source>
        <translation>Zentral Europäisch</translation>
    </message>
    <message>
        <source>Baltic</source>
        <translation>Baltisch</translation>
    </message>
    <message>
        <source>Cyrillic</source>
        <translation>Kyrillisch</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Arabisch</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Griechisch</translation>
    </message>
    <message>
        <source>Hebrew, visually ordered</source>
        <translation>Hebräisch, visuell angeordnet</translation>
    </message>
    <message>
        <source>Hebrew, logically ordered</source>
        <translation>Hebräisch, logisch angeordnet</translation>
    </message>
    <message>
        <source>Turkish</source>
        <translation>Türkisch</translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation>Hebräisch</translation>
    </message>
    <message>
        <source>Thai</source>
        <translation>Thailändisch</translation>
    </message>
    <message>
        <source>Qtel: Password mismatch</source>
        <translation>Qtel: falsches Passwort</translation>
    </message>
    <message>
        <source>Passwords do not match</source>
        <translation>Passworte stimmen nicht überein</translation>
    </message>
    <message>
        <source>Sound Settings</source>
        <translation>Audioeinstellungen</translation>
    </message>
    <message>
        <source>Mic audio device</source>
        <translation>Audio Eingabegerät</translation>
    </message>
    <message>
        <source>The audio device to use (e.g. alsa:default)</source>
        <translation>Verwendetes Audio Gerät (z.B. alsa:default)</translation>
    </message>
    <message>
        <source>Speaker audio device</source>
        <translation>Audio Ausgabegerät</translation>
    </message>
    <message>
        <source>QSO Dialog Settings</source>
        <translation>QSO Dialog Einstellungen</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Servers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A space separated list of the hostname or IP address of the EchoLink directory servers to use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EchoLink Proxy Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If enabling EchoLink proxy you must supply a proxy server hostname or IP address.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The hostname or IP address of the EchoLink proxy server to use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TCP Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The TCP port to connect to on the EchoLink proxy server, default 8100</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The EchoLink PROXY password, not your normal EchoLink password. Leave empty for public proxy.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EchoLink proxy configuration problem</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EchoLink proxy enabled but no server given</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bind address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;A bind address can be specified to force Qtel to use a specific network interface if your computer has more than one. Specify the IP address of the interface to bind to.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
